# API Updates
[Poll API Deprecation: Transition to the New Survey API](https://help.sap.com/docs/leanix/ea/poll-api-updates-transition-to-new-survey-api?locale=en-US&state=PRODUCTION&version=CLOUD "Learn what's changing and how to prepare for the transition to the new API for surveys.")
[GraphQL API: Error Handling for Multiple Mutations Sent in a Single Request (July 28, 2025)](https://help.sap.com/docs/leanix/ea/api-updates-graphql-error-handling?locale=en-US&state=PRODUCTION&version=CLOUD)
[Self-Built Software Discovery API: Asynchronous Processing of SBOM File Ingestions (April 7, 2025)](https://help.sap.com/docs/leanix/ea/api-updates-sbom-async-processing?locale=en-US&state=PRODUCTION&version=CLOUD "Learn what’s changing in the Self-Built Software Discovery API and how to prepare for these changes to avoid any issues with your integrations.")
[GraphQL API Changes (January 15, 2025)](https://help.sap.com/docs/leanix/ea/api-updates-graphql-api-changes?locale=en-US&state=PRODUCTION&version=CLOUD "Learn what's changing in our GraphQL API and how to prepare for these changes to avoid any issues with your integrations.")
YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
